# Odd Even Game
This is a game in which you have to play cricket with computer.

You have to choose odd or even and then you have to choose a number between 1 to 10.

## How to import this project
1. Open your terminal
2. Type `pip install OddEvenGame` and hit enter

## How to use this project
   type `.start()` to run the game

## Example
```
import oddevengame
oddevengame.start()
```
